%{?!_licensedir:%global license %%doc}
%{!?upstream_version: %global upstream_version %{version}}

%global sname ironic-python-agent

Name:       openstack-ironic-python-agent
Summary:    A python agent for provisioning and deprovisioning bare metal servers
Version:    1.5.2
Release:    6%{?dist}
License:    ASL 2.0
URL:        https://github.com/openstack/ironic-python-agent

Source0:    http://tarballs.openstack.org/%{sname}/%{sname}-%{upstream_version}.tar.gz

#
# patches_ignore=DROP-IN-RPM
# patches_base=1.5.2
#
Patch0001: 0001-Revert-Adjust-whitespace-in-setup.cfg.patch
Patch0002: 0002-imagebuild-support-requirements-referring-to-opt-sta.patch
Patch0003: 0003-NUMA-topology-collector.patch
Patch0004: 0004-Fix-compatibility-with-Pint-0.5.patch
Patch0005: 0005-Make-root_device-hints-case-insensitive.patch
Patch0006: 0006-Report-dev-disk-by-path-on-inspection.patch
Patch0007: 0007-LLDP-Skip-NICs-that-say-they-are-ready-but-are-unrea.patch
Patch0008: 0008-Fix-waiting-for-target-disk-to-appear.patch

Source1:    openstack-ironic-python-agent.service

BuildArch:  noarch
BuildRequires:  python-setuptools
BuildRequires:  python-pbr
BuildRequires:  python2-devel
BuildRequires:  systemd
Requires: python-ironic-python-agent = %{upstream_version}
Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd

# TODO(trown) when the following packages are available, package for py3:
# python3-eventlet
# python3-oslo-concurrency
# python3-oslo-log
# python3-oslo-serialization
# python3-oslo-service
# python3-oslo-utils
# python3-pecan
# python3-pint
# python3-wsme

%description
An agent for controlling and deploying Ironic controlled bare metal nodes.

The ironic-python-agent works with the agent driver in Ironic to provision the
node. Starting with ironic-python-agent running on a ramdisk on the
unprovisioned node, Ironic makes API calls to ironic-python-agent to provision
the machine. This allows for greater control and flexibility of the entire
deployment process.

The ironic-python-agent may also be used with the original Ironic pxe drivers
as of the Kilo OpenStack release.

%package -n python-ironic-python-agent
Summary:    Python library for the ironic python agent.
%{?python_provide:%python_provide python-ironic-python-agent}
# python_provide does not exist in CBS Cloud buildroot
Provides:   python-ironic-python-agent = %{upstream_version}

Requires: python-pbr
Requires: python-eventlet
Requires: python-ironic-lib
Requires: python-iso8601
Requires: python-netifaces
Requires: python-oslo-config
Requires: python-oslo-concurrency
Requires: python-oslo-log
Requires: python-oslo-serialization
Requires: python-oslo-service
Requires: python-oslo-utils
Requires: python-pecan
Requires: python-pint
Requires: python-psutil
Requires: python-pyudev
Requires: python-requests
Requires: python-rtslib
Requires: python-six
Requires: python-stevedore
Requires: python-wsme

%description -n python-ironic-python-agent
Python library for ironic python agent.

%package -n python-ironic-python-agent-doc
Summary:    Documentation for ironic python agent.
%{?python_provide:%python_provide python-ironic-python-agent-doc}
# python_provide does not exist in CBS Cloud buildroot
Provides:   python-ironic-python-agent-doc = %{upstream_version}

%description -n python-ironic-python-agent-doc
Documentation for ironic python agent.

%prep
%autosetup -v -p 1 -n ironic-python-agent-%{upstream_version}

# Remove the requirements file so that pbr hooks don't add it
# to distutils requires_dist config
rm -rf {test-,}requirements.txt tools/{pip,test}-requires

%build
%{__python2} setup.py build

%install
%{__python2} setup.py install -O1 --skip-build --root=%{buildroot}

# TODO(trown) build the docs as below once we either remove the upstream
# requirement on python-sphinxcontrib-pecanwsme, or it exists in rawhide.
# For now, we will just include the raw restructured text.
# export PYTHONPATH="$( pwd ):$PYTHONPATH"
# pushd doc
# sphinx-build -b html -d build/doctrees  source build/html
# popd

# install systemd scripts
mkdir -p %{buildroot}%{_unitdir}
install -p -D -m 644 %{SOURCE1} %{buildroot}%{_unitdir}

install -p -D -m 644 etc/ironic_python_agent/ironic_python_agent.conf.sample %{buildroot}/%{_sysconfdir}/ironic-python-agent/agent.conf

%files
%doc README.rst
%license LICENSE
%config(noreplace) %attr(-,root,root) %{_sysconfdir}/ironic-python-agent
%{_bindir}/ironic-python-agent
%{_unitdir}/openstack-ironic-python-agent.service

%files -n python-ironic-python-agent
%license LICENSE
%{python2_sitelib}/ironic_python_agent
%{python2_sitelib}/ironic_python_agent*.egg-info

%files -n python-ironic-python-agent-doc
%doc doc/source
%license LICENSE

%post
%systemd_post openstack-ironic-python-agent.service

%preun
%systemd_preun openstack-ironic-python-agent.service

%postun
%systemd_postun_with_restart openstack-ironic-python-agent.service

%changelog
* Thu Aug 16 2018 Bob Fournier <bfournie@redhat.com> 1.5.2-6
- Fix waiting for target disk to appear (rhbz#1430758)

* Thu May 24 2018 Bob Fournier <bfournie@redhat.com> 1.5.2-5
- [LLDP] Skip NICs that say they are ready but are unreadable. (rhbz#1582168)

* Thu May 03 2018 Bob Fournier <bfournie@redhat.com> 1.5.2-4
- Report /dev/disk/by-path on inspection (rhbz#1565295)

* Mon Feb 05 2018 Jaganathan Palanisamy <jpalanis@redhat.com> 1.5.2-3
- Resolves: rhbz#1501875
- Make root_device hints case insensitive (rhbz#1452226)
- Fix compatibility with Pint 0.5
- NUMA-topology collector
- Revert "Adjust whitespace in setup.cfg"

* Fri Aug 04 2017 Steve Linabery <slinaber@redhat.com> 1.5.2-2
- [imagebuild] support requirements referring to /opt/stack/new

* Fri Aug 04 2017 Steve Linabery <slinaber@redhat.com> 1.5.2-1
- Update to 1.5.2

* Fri May 19 2017 Jason Joyce <jjoyce@redhat.com> 1.5.1-3
- Support psutil 5.0.1

* Mon Mar 13 2017 Jon Schlueter <jschluet@redhat.com> 1.5.1-2
- rebase to upstream/stable/newton (rhbz#1431813)
- [TinyIPA] Avoid running rm with no parameters
- Limit memory usage when running qemu-img convert
- Revert "Use liberty-eol tag for liberty release notes"
- Use liberty-eol tag for liberty release notes
- Skip API related work if no api url configured

* Fri Jan 13 2017 Jon Schlueter <jschluet@redhat.com> 1.5.1-1
- Update to 1.5.1 (rhbz#1412911)

* Thu Nov 17 2016 Jason Joyce <jjoyce@redhat.com> 1.5.0-4
- Updated from global requirements

* Mon Nov 14 2016 Jason Joyce <jjoyce@redhat.com> 1.5.0-3
- Fix several errors in LLDP handling code

* Mon Nov 07 2016 Jon Schlueter <jschluet@redhat.com> 1.5.0-2
- Fix config drive writing script
- Update UPPER_CONSTRAINTS_FILE for stable/newton

* Thu Sep 22 2016 Haikel Guemar <hguemar@fedoraproject.org> 1.5.0-1
- Update to 1.5.0

* Wed Sep 14 2016 Haikel Guemar <hguemar@fedoraproject.org> 1.4.0-1
- Update to 1.4.0

